#!/usr/local/bin/perl

# astrotally.pl
# by Apollia of Astroblahhh.Com - http://astroblahhh.com/ Completed July 19, 2004.

# Public domain.


# INFORMATION FOR THIS PROGRAM 
#
# This is a script for converting Astrolog 5.40 output like the following:
#
#Astrolog 5.40 chart for Fri Jul  3, 1981 12:50pm (DT -5:00 GMT)  79:59W 40:26N
#Body  Locat. Ret. Lati. Rul.      House  Rul. Veloc.    Placidus Houses.
#
#Sun : 11Can39   + 0:00' (-) [10th house] [-] +0.953  -  House cusp  1:  3Lib18
#Moon:  7Leo02   + 0:29' (-) [10th house] [F] +13.92  -  House cusp  2: 29Lib39
#Merc: 26Gem20   - 4:30' (R) [ 9th house] [F] +0.065  -  House cusp  3:  0Sag13
#Venu:  4Leo41   + 1:34' (-) [10th house] [-] +1.216  -  House cusp  4:  3Cap48
#Mars: 19Gem59   + 0:19' (-) [ 9th house] [-] +0.689  -  House cusp  5:  7Aqu15
#Jupi:  2Lib24   + 1:17' (-) [12th house] [R] +0.103  -  House cusp  6:  7Pis29
#Satu:  3Lib41   + 2:24' (e) [ 1st house] [d] +0.048  -  House cusp  7:  3Ari18
#Uran: 26Sco28 R + 0:13' (e) [ 2nd house] [d] -0.025  -  House cusp  8: 29Ari39
#Nept: 22Sag59 R + 1:22' (e) [ 3rd house] [d] -0.025  -  House cusp  9:  0Gem13
#Plut: 21Lib32   +17:13' (-) [ 1st house] [-] +0.001  -  House cusp 10:  3Can48
#Chir: 21Tau26   - 2:15' (-) [ 8th house] [-] +0.048  -  House cusp 11:  7Leo15
#Node:  2Leo47 R + 0:00' (F) [10th house] [-] +0.053  -  House cusp 12:  7Vir29
#Lili: 20Sco48   + 4:54' (R) [ 2nd house] [F] +0.111
#Fort: 28Lib41   _______ (-) [ 1st house] [-] ______     Car Fix Mut TOT   +:12
#Vert:  9Ari09   _______ (F) [ 7th house] [R] ______  Fir  1   3   1   5   -: 5
#                                                     Ear  0   1   0   1   M: 9
#                                                     Air  5   0   2   7   N: 6
#                                                     Wat  2   2   0   4   A:11
#                                                     TOT  8   6   3  17   D: 4
#                                                                          <: 9
############
# ...into HTML forms usable in AstroTally.  It's faster than using the 
# JavaScript AstroTally Form Generator.  Just copy and paste Astrolog 5.40 
# output like the above into a text file titled "astroinputfile.txt" in the 
# same directory as the script, making sure the Sun's data is on line 4 of 
# the text file.  (I was feeling too lazy to figure out how to make it so 
# the program would recognize the data no matter what line it began on).
# The output will end up in a file called "astrooutputfile.txt".  The
# script doesn't need any arguments to run; running it by typing something 
# like "perl astrotally.pl" should suffice.


open(INPUTFILE,"astroinputfile.txt");
open(RESULTS, ">astrooutputfile.txt");

my $curline;

$quot="\"";

$h1hou=1; $h2hou=2; $h3hou=3; $h4hou=4; $h5hou=5; $h6hou=6;
$h7hou=7; $h8hou=8; $h9hou=9; $h10hou=10; $h11hou=11; $h12hou=12;

for ($linenum=0;$linenum<15;$linenum++)
{	$curline=<INPUTFILE>;

	if ($linenum==3)
	{	
		$sunsign=substr($curline,8,3);
		$sunsign=~tr/a-z/A-Z/;

		$sundeg=substr($curline,6,2);
		$sundeg=MakeIntoOneChar($sundeg);

		$sunmin=substr($curline,11,2);
		$sunmin=MakeIntoOneChar($sunmin);

		$sunhou=substr($curline,29,2);
		$sunhou=MakeIntoOneChar($sunhou);

		$h1deg=substr($curline,71,2);
		$h1deg=MakeIntoOneChar($h1deg);

		$h1sign=substr($curline,73,3);
		$h1sign=~tr/a-z/A-Z/;

		$h1min=substr($curline,76,2);
		$h1min=MakeIntoOneChar($h1min);
	}
	if ($linenum==4)
	{
		$moonsign=substr($curline,8,3);
		$moonsign=~tr/a-z/A-Z/;

		$moondeg=substr($curline,6,2);
		$moondeg=MakeIntoOneChar($moondeg);

		$moonmin=substr($curline,11,2);
		$moonmin=MakeIntoOneChar($moonmin);

		$moonhou=substr($curline,29,2);
		$moonhou=MakeIntoOneChar($moonhou);

		$h2deg=substr($curline,71,2);
		$h2deg=MakeIntoOneChar($h1deg);

		$h2sign=substr($curline,73,3);
		$h2sign=~tr/a-z/A-Z/;

		$h2min=substr($curline,76,2);
		$h2min=MakeIntoOneChar($h2min);
	}

	if ($linenum==5)
	{
		$mercsign=substr($curline,8,3);
		$mercsign=~tr/a-z/A-Z/;

		$mercdeg=substr($curline,6,2);
		$mercdeg=MakeIntoOneChar($mercdeg);

		$mercmin=substr($curline,11,2);
		$mercmin=MakeIntoOneChar($mercmin);

		$merchou=substr($curline,29,2);
		$merchou=MakeIntoOneChar($merchou);

		$h3deg=substr($curline,71,2);
		$h3deg=MakeIntoOneChar($h3deg);

		$h3sign=substr($curline,73,3);
		$h3sign=~tr/a-z/A-Z/;

		$h3min=substr($curline,76,2);
		$h3min=MakeIntoOneChar($h3min);
	}
	if ($linenum==6)
	{
		$venusign=substr($curline,8,3);
		$venusign=~tr/a-z/A-Z/;

		$venudeg=substr($curline,6,2);
		$venudeg=MakeIntoOneChar($venudeg);

		$venumin=substr($curline,11,2);
		$venumin=MakeIntoOneChar($venumin);

		$venuhou=substr($curline,29,2);
		$venuhou=MakeIntoOneChar($venuhou);

		$h4deg=substr($curline,71,2);
		$h4deg=MakeIntoOneChar($h4deg);

		$h4sign=substr($curline,73,3);
		$h4sign=~tr/a-z/A-Z/;

		$h4min=substr($curline,76,2);
		$h4min=MakeIntoOneChar($h4min);
	}
	if ($linenum==7)
	{
		$marssign=substr($curline,8,3);
		$marssign=~tr/a-z/A-Z/;

		$marsdeg=substr($curline,6,2);
		$marsdeg=MakeIntoOneChar($marsdeg);

		$marsmin=substr($curline,11,2);
		$marsmin=MakeIntoOneChar($marsmin);

		$marshou=substr($curline,29,2);
		$marshou=MakeIntoOneChar($marshou);

		$h5deg=substr($curline,71,2);
		$h5deg=MakeIntoOneChar($h5deg);

		$h5sign=substr($curline,73,3);
		$h5sign=~tr/a-z/A-Z/;

		$h5min=substr($curline,76,2);
		$h5min=MakeIntoOneChar($h5min);
	}
	if ($linenum==8)
	{
		$jupisign=substr($curline,8,3);
		$jupisign=~tr/a-z/A-Z/;

		$jupideg=substr($curline,6,2);
		$jupideg=MakeIntoOneChar($jupideg);

		$jupimin=substr($curline,11,2);
		$jupimin=MakeIntoOneChar($jupimin);

		$jupihou=substr($curline,29,2);
		$jupihou=MakeIntoOneChar($jupihou);

		$h6deg=substr($curline,71,2);
		$h6deg=MakeIntoOneChar($h6deg);

		$h6sign=substr($curline,73,3);
		$h6sign=~tr/a-z/A-Z/;

		$h6min=substr($curline,76,2);
		$h6min=MakeIntoOneChar($h6min);
	}
	if ($linenum==9)
	{
		$satusign=substr($curline,8,3);
		$satusign=~tr/a-z/A-Z/;

		$satudeg=substr($curline,6,2);
		$satudeg=MakeIntoOneChar($satudeg);

		$satumin=substr($curline,11,2);
		$satumin=MakeIntoOneChar($satumin);

		$satuhou=substr($curline,29,2);
		$satuhou=MakeIntoOneChar($satuhou);

		$h7deg=substr($curline,71,2);
		$h7deg=MakeIntoOneChar($h7deg);

		$h7sign=substr($curline,73,3);
		$h7sign=~tr/a-z/A-Z/;

		$h7min=substr($curline,76,2);
		$h7min=MakeIntoOneChar($h7min);
	}
	if ($linenum==10)
	{
		$uransign=substr($curline,8,3);
		$uransign=~tr/a-z/A-Z/;

		$urandeg=substr($curline,6,2);
		$urandeg=MakeIntoOneChar($urandeg);

		$uranmin=substr($curline,11,2);
		$uranmin=MakeIntoOneChar($uranmin);

		$uranhou=substr($curline,29,2);
		$uranhou=MakeIntoOneChar($uranhou);

		$h8deg=substr($curline,71,2);
		$h8deg=MakeIntoOneChar($h8deg);

		$h8sign=substr($curline,73,3);
		$h8sign=~tr/a-z/A-Z/;

		$h8min=substr($curline,76,2);
		$h8min=MakeIntoOneChar($h8min);
	}
	if ($linenum==11)
	{
		$neptsign=substr($curline,8,3);
		$neptsign=~tr/a-z/A-Z/;

		$neptdeg=substr($curline,6,2);
		$neptdeg=MakeIntoOneChar($neptdeg);

		$neptmin=substr($curline,11,2);
		$neptmin=MakeIntoOneChar($neptmin);

		$nepthou=substr($curline,29,2);
		$nepthou=MakeIntoOneChar($nepthou);

		$h9deg=substr($curline,71,2);
		$h9deg=MakeIntoOneChar($h9deg);

		$h9sign=substr($curline,73,3);
		$h9sign=~tr/a-z/A-Z/;

		$h9min=substr($curline,76,2);
		$h9min=MakeIntoOneChar($h9min);
	}
	if ($linenum==12)
	{
		$plutsign=substr($curline,8,3);
		$plutsign=~tr/a-z/A-Z/;

		$plutdeg=substr($curline,6,2);
		$plutdeg=MakeIntoOneChar($plutdeg);

		$plutmin=substr($curline,11,2);
		$plutmin=MakeIntoOneChar($plutmin);

		$pluthou=substr($curline,29,2);
		$pluthou=MakeIntoOneChar($pluthou);

		$h10deg=substr($curline,71,2);
		$h10deg=MakeIntoOneChar($h10deg);

		$h10sign=substr($curline,73,3);
		$h10sign=~tr/a-z/A-Z/;

		$h10min=substr($curline,76,2);
		$h10min=MakeIntoOneChar($h10min);
	}
	if ($linenum==13)
	{

		$h11deg=substr($curline,71,2);
		$h11deg=MakeIntoOneChar($h11deg);

		$h11sign=substr($curline,73,3);
		$h11sign=~tr/a-z/A-Z/;

		$h11min=substr($curline,76,2);
		$h11min=MakeIntoOneChar($h11min);
	}
	if ($linenum==14)
	{
		$nodesign=substr($curline,8,3);
		$nodesign=~tr/a-z/A-Z/;

		$snodesign=GetOppSign($nodesign);

		$nodedeg=substr($curline,6,2);
		$nodedeg=MakeIntoOneChar($nodedeg);

		$nodemin=substr($curline,11,2);
		$nodemin=MakeIntoOneChar($nodemin);

		$nodehou=substr($curline,29,2);
		$nodehou=MakeIntoOneChar($nodehou);

		if ($nodehou>6)
		{	$snodehou=$nodehou-6;
		}
		elsif ($nodehou<6)
		{	$snodehou=$nodehou+6;
		};

		$h12deg=substr($curline,71,2);
		$h12deg=MakeIntoOneChar($h12deg);

		$h12sign=substr($curline,73,3);
		$h12sign=~tr/a-z/A-Z/;

		$h12min=substr($curline,76,2);
		$h12deg=MakeIntoOneChar($h12deg);
	}
}

	PrintForms();


sub PrintForms
{	print RESULTS "<table border><tr><th colspan=12>Planets<tr><th>SU<th>MO<th>ME<th>VE<th>MA<th>JU<th>SA<th>UR<th>NE<th>PL<th>South Node<th>North Node<tr>";
	print RESULTS "<td><form name=SUData><input type=text size=8 name=SUSign value=$sunsign><br><input type=text size=1 name=SUDegree value=$sundeg><input type=text size=1 name=SUMinute value=$sunmin><br><input type=text size=2 name=SUDegree360><br><input type=text size=1 name=SUHouse value=$sunhou></form>";
	print RESULTS "<td><form name=MOData><input type=text size=8 name=MOSign value=$moonsign><br><input type=text size=1 name=MODegree value=$moondeg><input type=text size=1 name=MOMinute value=$moonmin><br><input type=text size=2 name=MODegree360><br><input type=text size=1 name=MOHouse value=$moonhou></form>";
	print RESULTS "<td><form name=MEData><input type=text size=8 name=MESign value=$mercsign><br><input type=text size=1 name=MEDegree value=$mercdeg><input type=text size=1 name=MEMinute value=$mercmin><br><input type=text size=2 name=MEDegree360><br><input type=text size=1 name=MEHouse value=$merchou></form>";
	print RESULTS "<td><form name=VEData><input type=text size=8 name=VESign value=$venusign><br><input type=text size=1 name=VEDegree value=$venudeg><input type=text size=1 name=VEMinute value=$venumin><br><input type=text size=2 name=VEDegree360><br><input type=text size=1 name=VEHouse value=$venuhou></form>";
	print RESULTS "<td><form name=MAData><input type=text size=8 name=MASign value=$marssign><br><input type=text size=1 name=MADegree value=$marsdeg><input type=text size=1 name=MAMinute value=$marsmin><br><input type=text size=2 name=MADegree360><br><input type=text size=1 name=MAHouse value=$marshou></form>";
	print RESULTS "<td><form name=JUData><input type=text size=8 name=JUSign value=$jupisign><br><input type=text size=1 name=JUDegree value=$jupideg><input type=text size=1 name=JUMinute value=$jupimin><br><input type=text size=2 name=JUDegree360><br><input type=text size=1 name=JUHouse value=$jupihou></form>";
	print RESULTS "<td><form name=SAData><input type=text size=8 name=SASign value=$satusign><br><input type=text size=1 name=SADegree value=$satudeg><input type=text size=1 name=SAMinute value=$satumin><br><input type=text size=2 name=SADegree360><br><input type=text size=1 name=SAHouse value=$satuhou></form>";
	print RESULTS "<td><form name=URData><input type=text size=8 name=URSign value=$uransign><br><input type=text size=1 name=URDegree value=$urandeg><input type=text size=1 name=URMinute value=$uranmin><br><input type=text size=2 name=URDegree360><br><input type=text size=1 name=URHouse value=$uranhou></form>";
	print RESULTS "<td><form name=NEData><input type=text size=8 name=NESign value=$neptsign><br><input type=text size=1 name=NEDegree value=$neptdeg><input type=text size=1 name=NEMinute value=$neptmin><br><input type=text size=2 name=NEDegree360><br><input type=text size=1 name=NEHouse value=$nepthou></form>";
	print RESULTS "<td><form name=PLData><input type=text size=8 name=PLSign value=$plutsign><br><input type=text size=1 name=PLDegree value=$plutdeg><input type=text size=1 name=PLMinute value=$plutmin><br><input type=text size=2 name=PLDegree360><br><input type=text size=1 name=PLHouse value=$pluthou></form>";\
	print RESULTS "<td><form name=SNData><input type=text size=8 name=SNSign value=$snodesign><br><input type=text size=1 name=SNDegree value=$nodedeg><input type=text size=1 name=SNMinute value=$nodemin><br><input type=text size=2 name=SNDegree360><br><input type=text size=1 name=SNHouse value=$snodehou></form>";
	print RESULTS "<td><form name=NNData><input type=text size=8 name=NNSign value=$nodesign><br><input type=text size=1 name=NNDegree value=$nodedeg><input type=text size=1 name=NNMinute value=$nodemin><br><input type=text size=2 name=NNDegree360><br><input type=text size=1 name=NNHouse value=$nodehou></form></table>";

	print RESULTS "<! Forms 10-21: the houses' sign, degree, minute and house data.><tr><td><table border><tr><th colspan=12>Houses<tr><th>House 1<th>House 2<th>House 3<th>House 4<th>House 5<th>House 6<th>House 7<th>House 8<th>House 9<th>House 10<th>House 11<th>House 12<tr>";

	print RESULTS "<td><form name=H1Data><input type=text size=8 name=H1Sign value=$h1sign><br><input type=text size=1 name=H1Degree value=$h1deg><input type=text size=1 name=H1Minute value=$h1min><br><input type=text size=2 name=H1Degree360><br><input type=text size=1 name=H1House value=$h1hou></form>";

	print RESULTS "<td><form name=h2Data><input type=text size=8 name=h2Sign value=$h2sign><br><input type=text size=1 name=h2Degree value=$h2deg><input type=text size=1 name=h2Minute value=$h2min><br><input type=text size=2 name=h2Degree360><br><input type=text size=1 name=h2House value=$h2hou></form>";

	print RESULTS "<td><form name=h3Data><input type=text size=8 name=h3Sign value=$h3sign><br><input type=text size=1 name=h3Degree value=$h3deg><input type=text size=1 name=h3Minute value=$h3min><br><input type=text size=2 name=h3Degree360><br><input type=text size=1 name=h3House value=$h3hou></form>";

	print RESULTS "<td><form name=h4Data><input type=text size=8 name=h4Sign value=$h4sign><br><input type=text size=1 name=h4Degree value=$h4deg><input type=text size=1 name=h4Minute value=$h4min><br><input type=text size=2 name=h4Degree360><br><input type=text size=1 name=h4House value=$h4hou></form>";

	print RESULTS "<td><form name=h5Data><input type=text size=8 name=h5Sign value=$h5sign><br><input type=text size=1 name=h5Degree value=$h5deg><input type=text size=1 name=h5Minute value=$h5min><br><input type=text size=2 name=h5Degree360><br><input type=text size=1 name=h5House value=$h5hou></form>";

	print RESULTS "<td><form name=h6Data><input type=text size=8 name=h6Sign value=$h6sign><br><input type=text size=1 name=h6Degree value=$h6deg><input type=text size=1 name=h6Minute value=$h6min><br><input type=text size=2 name=h6Degree360><br><input type=text size=1 name=h6House value=$h6hou></form>";

	print RESULTS "<td><form name=h7Data><input type=text size=8 name=h7Sign value=$h7sign><br><input type=text size=1 name=h7Degree value=$h7deg><input type=text size=1 name=h7Minute value=$h7min><br><input type=text size=2 name=h7Degree360><br><input type=text size=1 name=h7House value=$h7hou></form>";

	print RESULTS "<td><form name=h8Data><input type=text size=8 name=h8Sign value=$h8sign><br><input type=text size=1 name=h8Degree value=$h8deg><input type=text size=1 name=h8Minute value=$h8min><br><input type=text size=2 name=h8Degree360><br><input type=text size=1 name=h8House value=$h8hou></form>";

	print RESULTS "<td><form name=h9Data><input type=text size=8 name=h9Sign value=$h9sign><br><input type=text size=1 name=h9Degree value=$h9deg><input type=text size=1 name=h9Minute value=$h9min><br><input type=text size=2 name=h9Degree360><br><input type=text size=1 name=h9House value=$h9hou></form>";

	print RESULTS "<td><form name=h10Data><input type=text size=8 name=h10Sign value=$h10sign><br><input type=text size=1 name=h10Degree value=$h10deg><input type=text size=1 name=h10Minute value=$h10min><br><input type=text size=2 name=h10Degree360><br><input type=text size=1 name=h10House value=$h10hou></form>";

	print RESULTS "<td><form name=h11Data><input type=text size=8 name=h11Sign value=$h11sign><br><input type=text size=1 name=h11Degree value=$h11deg><input type=text size=1 name=h11Minute value=$h11min><br><input type=text size=2 name=h11Degree360><br><input type=text size=1 name=h11House value=$h11hou></form>";

	print RESULTS "<td><form name=h12Data><input type=text size=8 name=h12Sign value=$h12sign><br><input type=text size=1 name=h12Degree value=$h12deg><input type=text size=1 name=h12Minute value=$h12min><br><input type=text size=2 name=h12Degree360><br><input type=text size=1 name=h12House value=$h12hou></form>";

	print RESULTS "</table>";
	print "Done; results should be in astrooutputfile.txt.\n";
}

sub GetOppSign
{	$cursign=$_[0];
	if ($cursign eq "ARI")
	{	$oppsign="LIB";
	}
	elsif ($cursign eq "TAU")
	{	$oppsign="SCO";
	}
	elsif ($cursign eq "GEM")
	{	$oppsign="SAG";
	}
	elsif ($cursign eq "CAN")
	{	$oppsign="CAP";
	}
	elsif ($cursign eq "LEO")
	{	$oppsign="AQU";
	}
	elsif ($cursign eq "VIR")
	{	$oppsign="PIS";
	}
	elsif ($cursign eq "LIB")
	{	$oppsign="ARI";
	}
	elsif ($cursign eq "SCO")
	{	$oppsign="TAU";
	}
	elsif ($cursign eq "SAG")
	{	$oppsign="GEM";
	}
	elsif ($cursign eq "CAP")
	{	$oppsign="CAN";
	}
	elsif ($cursign eq "AQU")
	{	$oppsign="LEO";
	}
	elsif ($cursign eq "PIS")
	{	$oppsign="VIR";
	};
	return $oppsign;
}

sub RemoveZeroDecimal
{	$newstr=substr($_[0],0,100);
	$newstr=substr($newstr,2,100);
	return $newstr;
}

sub MakeIntoOneChar
{	$firstchar=substr($_[0],0,1);
	if ($firstchar==" " || $firstchar=="0")
	{	$secondchar=substr($_[0],1,1);
		return $secondchar;
	}
	return $_[0];
}